"""Data wrangler factory."""


# .....................................................................................
def wrangler_factory(wrangler_configs):
    """Factory for instantiating data wranglers.

    Args:
        wrangler_configs (list of dict): A list of wrangler configuration dictionaries.

    Returns:
        list: A list of data wranglers.
    """
    wranglers = []
    for _config in wrangler_configs:
        pass
    return wranglers
